# Pipiy

`pipiy` is a tool for managing pip packages using WSON formatted requirements files, similar to Gradle or Maven.

## Installation

Clone the repository and install it:

```bash
pip install pipiy
```

```bash
pipiy init
```

```bash
pipiy install [module]
```